summaryrefslogtreecommitdiff
path: root/testsuite/tests/ghc-api/T7478/T7478.hs
diff options
context:
space:
mode:
Diffstat (limited to 'testsuite/tests/ghc-api/T7478/T7478.hs')
-rw-r--r--testsuite/tests/ghc-api/T7478/T7478.hs7
1 files changed, 4 insertions, 3 deletions
diff --git a/testsuite/tests/ghc-api/T7478/T7478.hs b/testsuite/tests/ghc-api/T7478/T7478.hs
index 87739ec110..dbea3f9547 100644
--- a/testsuite/tests/ghc-api/T7478/T7478.hs
+++ b/testsuite/tests/ghc-api/T7478/T7478.hs
@@ -14,9 +14,10 @@ import qualified GHC.Driver.Ppr as GHC
import GHC.Driver.Monad (liftIO)
import GHC.Utils.Outputable (PprStyle, queryQual)
import GHC.Unit.State
+import GHC.Types.Error
compileInGhc :: [FilePath] -- ^ Targets
- -> (String -> IO ()) -- ^ handler for each SevOutput message
+ -> (String -> IO ()) -- ^ handler for each MCOutput message
-> Ghc ()
compileInGhc targets handlerOutput = do
-- Set flags
@@ -47,9 +48,9 @@ compileInGhc targets handlerOutput = do
TargetFile file Nothing -> file
_ -> error "fileFromTarget: not a known target"
- collectSrcError handlerOutput flags _ SevOutput _srcspan msg
+ collectSrcError handlerOutput flags MCOutput _srcspan msg
= handlerOutput $ GHC.showSDocForUser flags emptyUnitState alwaysQualify msg
- collectSrcError _ _ _ _ _ _
+ collectSrcError _ _ _ _ _
= return ()
main :: IO ()